# ai-assistant
Small terminal AI assistant for generating content.

## Installation

Install `ai-assistant`: [`pip install -U ai-assistant`](https://pypi.org/project/ai-assistant/)

## Copyright
Created by Grzegorz Grzęda. Distributed under MIT license